# CI configuration plugin

This plugin is used for CI configuration projects when `PROGRAMMING_LANGUAGE` is set to `ci`.

This plugin is primarily dedicated to managing GitHub Actions and workflows but could be used for other CI systems.

## Release
The plugin only carries out git actions during release (git tags)

## Documentation
The plugin does not generate any documentation.